from enum import Enum


class Type(Enum):
    post = "post"
    comment = "comment"
    photo = "photo"
    audio = "audio"
    video = "video"
    note = "note"
    market = "market"
    photo_comment = "photo_comment"
    video_comment = "video_comment"
    topic_comment = "topic_comment"
    market_comment = "market_comment"
    sitepage = "sitepage"
